@@ -5,7 +5,7 @@
  *
  */
 #include "luaaddonstate.h"
-#include "baselua.h"
+#include "base.lua.h"
 #include <fcitx-utils/standardpath.h>
 #include <fcitx-utils/utf8.h>
 #include <fcitx/addonmanager.h>
@@ -46,7 +46,7 @@ static void LuaPrintError(LuaState *lua) {
     }
 }
 
-LuaAddonState::LuaAddonState(Library &luaLibrary, const std::string &name,
+LuaAddonState::LuaAddonState(Library *luaLibrary, const std::string &name,
                              const std::string &library, AddonManager *manager)
     : instance_(manager->instance()),
       state_(std::make_unique<LuaState>(luaLibrary)) {
@@ -92,7 +92,7 @@ LuaAddonState::LuaAddonState(Library &luaLibrary, const std::string &name,
     };
     auto open_fcitx = [](lua_State *state) {
         auto s = GetLuaAddonState(state)->state_.get();
-        if (int rv = luaL_loadstring(s, baselua) ||
+        if (int rv = luaL_loadstring(s, baseLua) ||
                      lua_pcallk(s, 0, LUA_MULTRET, 0, 0, nullptr);
             rv != LUA_OK) {
             LuaPError(rv, "luaL_loadbuffer() failed");
